NeoTokens class

Provides the NeoTokens API for Neo-Brutalist Flutter interfaces.

Constructors

NeoTokens()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

borderWidth → const double
Static borderWidth value used by the component system.
compactShadowOffset → const Offset
Static compactShadowOffset value used by the component system.
radiusLarge → const double
Static radiusLarge value used by the component system.
radiusMedium → const double
Static radiusMedium value used by the component system.
radiusSmall → const double
Static radiusSmall value used by the component system.
shadowOffset → const Offset
Static shadowOffset value used by the component system.