NeoMoonSpec class
Provides the NeoMoonSpec API for Neo-Brutalist Flutter interfaces.
Constructors
- NeoMoonSpec({required double leftFactor, required double topFactor, required double size, required Color color, required Color shadowColor, required Color pageColor, required Color borderColor, required double xTravel, required double yTravel, double phase = 0.3})
-
Creates a NeoMoonSpec instance.
const
Properties
- borderColor → Color
-
The borderColor value used to configure this component.
final
- color → Color
-
The color value used to configure this component.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- leftFactor → double
-
The leftFactor value used to configure this component.
final
- pageColor → Color
-
The pageColor value used to configure this component.
final
- phase → double
-
The phase value used to configure this component.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowColor → Color
-
The shadowColor value used to configure this component.
final
- size → double
-
The size value used to configure this component.
final
- topFactor → double
-
The topFactor value used to configure this component.
final
- xTravel → double
-
The xTravel value used to configure this component.
final
- yTravel → double
-
The yTravel value used to configure this component.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited