NeoOrbSpec class

Constructors

NeoOrbSpec({required double leftFactor, required double topFactor, required double size, required Color color, required Color shadowColor, required Color borderColor, required double xTravel, required double yTravel, double phase = 0.3})
const

Properties

borderColor Color
final
color Color
final
hashCode int
The hash code for this object.
no setterinherited
leftFactor double
final
phase double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowColor Color
final
size double
final
topFactor double
final
xTravel double
final
yTravel double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited