NeoBreakpoints class

Provides the NeoBreakpoints API for Neo-Brutalist Flutter interfaces.

Constructors

NeoBreakpoints()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

compact → const double
Static compact value used by the component system.
medium → const double
Static medium value used by the component system.
pageMaxWidth → const double
Static pageMaxWidth value used by the component system.