NeoSplitLayout class

Provides the NeoSplitLayout API for Neo-Brutalist Flutter interfaces.

Inheritance

Constructors

NeoSplitLayout({Key? key, required Widget primary, required Widget secondary, double collapseBreakpoint = NeoBreakpoints.medium, int primaryFlex = 6, int secondaryFlex = 4})
Creates a NeoSplitLayout instance.
const

Properties

collapseBreakpoint double
The collapseBreakpoint value used to configure this component.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
primary Widget
The primary value used to configure this component.
final
primaryFlex int
The primaryFlex value used to configure this component.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary Widget
The secondary value used to configure this component.
final
secondaryFlex int
The secondaryFlex value used to configure this component.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited