SplashConfig class
Provides the SplashConfig API for Neo-Brutalist Flutter interfaces.
Constructors
-
SplashConfig({required Duration initialDuration, required Duration buildDuration, required Duration fillDuration, required Duration revealDuration, required Duration settleDuration, required Duration exitDuration, required Size logoFrameSize, required double liquidAmplitude, required double liquidHighlightStrength, required double motionIntensity, required List<
SplashShapeSpec> shapes, required List<SplashCargoSpec> fillCargo, required List<SplashBubbleSpec> bubbleWave, required List<SplashBackdropSpec> backdrops}) -
Creates a SplashConfig instance.
const
- SplashConfig.neo()
-
Creates a SplashConfig instance.
Creates the default Neo-Brutalist splash animation configuration.
factory
Properties
-
backdrops
→ List<
SplashBackdropSpec> -
The backdrops value used to configure this component.
final
-
bubbleWave
→ List<
SplashBubbleSpec> -
The bubbleWave value used to configure this component.
final
- buildDuration → Duration
-
The buildDuration value used to configure this component.
final
- buildStart → double
-
Computed buildStart value for this instance.
no setter
- exitDuration → Duration
-
The exitDuration value used to configure this component.
final
- exitStart → double
-
Computed exitStart value for this instance.
no setter
-
fillCargo
→ List<
SplashCargoSpec> -
The fillCargo value used to configure this component.
final
- fillDuration → Duration
-
The fillDuration value used to configure this component.
final
- fillStart → double
-
Computed fillStart value for this instance.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialDuration → Duration
-
The initialDuration value used to configure this component.
final
- liquidAmplitude → double
-
The liquidAmplitude value used to configure this component.
final
- liquidHighlightStrength → double
-
The liquidHighlightStrength value used to configure this component.
final
- logoFrameSize → Size
-
The logoFrameSize value used to configure this component.
final
- motionIntensity → double
-
The motionIntensity value used to configure this component.
final
- revealDuration → Duration
-
The revealDuration value used to configure this component.
final
- revealStart → double
-
Computed revealStart value for this instance.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settleDuration → Duration
-
The settleDuration value used to configure this component.
final
- settleStart → double
-
Computed settleStart value for this instance.
no setter
-
shapes
→ List<
SplashShapeSpec> -
The shapes value used to configure this component.
final
- totalDuration → Duration
-
Computed totalDuration value for this instance.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
phaseFor(
double timelineProgress) → SplashPhase - Executes phaseFor for this component.
-
progressForPhase(
SplashPhase phase, double timelineProgress, {Curve curve = Curves.linear}) → double - Executes progressForPhase for this component.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited