SplashShapeSpec class

Constructors

SplashShapeSpec({required Alignment startAlignment, required Alignment targetAlignment, required Size size, required SplashColorRole colorRole, required SplashShapeKind kind, required double entryDelay, required double entrySpan, required Offset sway, required double hover, required double rotateTurns, required double liquidLift, required double impactBias, double? radius})
const

Properties

colorRole SplashColorRole
final
entryDelay double
final
entrySpan double
final
hashCode int
The hash code for this object.
no setterinherited
hover double
final
impactBias double
final
kind SplashShapeKind
final
liquidLift double
final
radius double?
final
rotateTurns double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
final
startAlignment Alignment
final
sway Offset
final
targetAlignment Alignment
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited