SplashThemeData class

Constructors

SplashThemeData({required List<Color> pageGradient, required Color atmosphereGlow, required Color surface, required Color surfaceAlt, required Color primary, required Color primarySoft, required Color outline, required Color shadowStrong, required Color shadowSoft, required Color textPrimary, required Color textMuted, required Color highlight})
const
SplashThemeData.fromPalette(NeoPalette palette)
factory

Properties

atmosphereGlow Color
final
hashCode int
The hash code for this object.
no setterinherited
highlight Color
final
outline Color
final
pageGradient List<Color>
final
primary Color
final
primarySoft Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowSoft Color
final
shadowStrong Color
final
surface Color
final
surfaceAlt Color
final
textMuted Color
final
textPrimary Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(SplashColorRole role) Color
resolveShadow(SplashColorRole role) Color
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited