FloatingShapeLayer class

Provides the FloatingShapeLayer API for Neo-Brutalist Flutter interfaces.

Inheritance

Constructors

FloatingShapeLayer({Key? key, required SplashConfig config, required SplashThemeData theme, required double timelineProgress, required double tensionProgress, required double buildProgress, required double fillProgress, required double revealProgress, required double settleProgress, required double exitProgress})
Creates a FloatingShapeLayer instance.
const

Properties

buildProgress double
The buildProgress value used to configure this component.
final
config SplashConfig
The config value used to configure this component.
final
exitProgress double
The exitProgress value used to configure this component.
final
fillProgress double
The fillProgress value used to configure this component.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
revealProgress double
The revealProgress value used to configure this component.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settleProgress double
The settleProgress value used to configure this component.
final
tensionProgress double
The tensionProgress value used to configure this component.
final
theme SplashThemeData
The theme value used to configure this component.
final
timelineProgress double
The timelineProgress value used to configure this component.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited