NeoAppSettingsSheet class

Provides the NeoAppSettingsSheet API for Neo-Brutalist Flutter interfaces.

Inheritance

Constructors

NeoAppSettingsSheet({Key? key, required ThemeMode themeMode, required NeoThemePreset preset, required ValueChanged<ThemeMode> onThemeModeChanged, required ValueChanged<NeoThemePreset> onPresetChanged, required VoidCallback onReset})
Creates a NeoAppSettingsSheet instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPresetChanged ValueChanged<NeoThemePreset>
The onPresetChanged value used to configure this component.
final
onReset VoidCallback
The onReset value used to configure this component.
final
onThemeModeChanged ValueChanged<ThemeMode>
The onThemeModeChanged value used to configure this component.
final
preset NeoThemePreset
The preset value used to configure this component.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
themeMode ThemeMode
The themeMode value used to configure this component.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited