NeoDataTableColumn class
Provides the NeoDataTableColumn API for Neo-Brutalist Flutter interfaces.
Constructors
- NeoDataTableColumn({required String label, int flex = 1, TextAlign textAlign = TextAlign.left})
-
Creates a NeoDataTableColumn instance.
const
Properties
- flex → int
-
The flex value used to configure this component.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
The label value used to configure this component.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textAlign → TextAlign
-
The textAlign value used to configure this component.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited