NeoOnboardingControls class
Provides the NeoOnboardingControls API for Neo-Brutalist Flutter interfaces.
Constructors
- NeoOnboardingControls({required NeoOnboardingWizardStep step, required int currentStep, required int totalSteps, required bool isFirst, required bool isLast, required bool isOptional, required VoidCallback onContinue, required VoidCallback onBack, required VoidCallback onSkip})
-
Creates a NeoOnboardingControls instance.
const
Properties
- currentStep → int
-
The currentStep value used to configure this component.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFirst → bool
-
The isFirst value used to configure this component.
final
- isLast → bool
-
The isLast value used to configure this component.
final
- isOptional → bool
-
The isOptional value used to configure this component.
final
- onBack → VoidCallback
-
The onBack value used to configure this component.
final
- onContinue → VoidCallback
-
The onContinue value used to configure this component.
final
- onSkip → VoidCallback
-
The onSkip value used to configure this component.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- step → NeoOnboardingWizardStep
-
The step value used to configure this component.
final
- totalSteps → int
-
The totalSteps value used to configure this component.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited