NeoOnboardingWizard class

Provides the NeoOnboardingWizard API for Neo-Brutalist Flutter interfaces.

Inheritance

Constructors

NeoOnboardingWizard({Key? key, required List<NeoOnboardingWizardStep> steps, bool showProgress = true, int initialIndex = 0, VoidCallback? onComplete, ValueChanged<int>? onStepChange, NeoOnboardingWizardStepChanged? onStepChanged, NeoOnboardingActionsBuilder? actionsBuilder})
Creates a NeoOnboardingWizard instance.
const

Properties

actionsBuilder NeoOnboardingActionsBuilder?
The actionsBuilder value used to configure this component.
final
hashCode int
The hash code for this object.
no setterinherited
initialIndex int
The initialIndex value used to configure this component.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onComplete VoidCallback?
The onComplete value used to configure this component.
final
onStepChange ValueChanged<int>?
The onStepChange value used to configure this component.
final
onStepChanged NeoOnboardingWizardStepChanged?
The onStepChanged value used to configure this component.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showProgress bool
The showProgress value used to configure this component.
final
steps List<NeoOnboardingWizardStep>
The steps value used to configure this component.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<NeoOnboardingWizard>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited