NeoOnboardingWizardStep class

Provides the NeoOnboardingWizardStep API for Neo-Brutalist Flutter interfaces.

Constructors

NeoOnboardingWizardStep({required String id, required String title, required Widget content, String? description, IconData? icon, bool optional = false})
Creates a NeoOnboardingWizardStep instance.
const

Properties

content Widget
The content value used to configure this component.
final
description String?
The description value used to configure this component.
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
The icon value used to configure this component.
final
id String
The id value used to configure this component.
final
optional bool
The optional value used to configure this component.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
The title value used to configure this component.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited