NeoStatusItem class

Provides the NeoStatusItem API for Neo-Brutalist Flutter interfaces.

Constructors

NeoStatusItem({required String label, NeoStatusTone tone = NeoStatusTone.neutral})
Creates a NeoStatusItem instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
The label value used to configure this component.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tone NeoStatusTone
The tone value used to configure this component.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited