NeoTabItem class

Provides the NeoTabItem API for Neo-Brutalist Flutter interfaces.

Constructors

NeoTabItem({required String label, IconData? icon})
Creates a NeoTabItem instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
icon IconData?
The icon value used to configure this component.
final
label String
The label value used to configure this component.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited