NeoTheme class
Constructors
- NeoTheme()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
buildTheme(
Brightness brightness, {NeoThemePreset preset = NeoThemePreset.worldSkills}) → ThemeData -
panelDecoration(
{required Color color, required Color shadowColor, required Color borderColor, double radius = NeoTokens.radiusLarge, Offset offset = NeoTokens.shadowOffset}) → BoxDecoration