NeoSpacing class
Provides the NeoSpacing API for Neo-Brutalist Flutter interfaces.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- lg → const double
- Static lg value used by the component system.
- md → const double
- Static md value used by the component system.
- sm → const double
- Static sm value used by the component system.
- xl → const double
- Static xl value used by the component system.
- xs → const double
- Static xs value used by the component system.
- xxl → const double
- Static xxl value used by the component system.