SplashBackdropSpec class
Constructors
- SplashBackdropSpec({required Alignment alignment, required Size size, required SplashColorRole colorRole, required SplashShapeKind kind, required Offset parallax, double? radius})
-
const
Properties
- alignment → Alignment
-
final
- colorRole → SplashColorRole
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → SplashShapeKind
-
final
- parallax → Offset
-
final
- radius → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → Size
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited