SplashBackdropSpec class

Provides the SplashBackdropSpec API for Neo-Brutalist Flutter interfaces.

Constructors

SplashBackdropSpec({required Alignment alignment, required Size size, required SplashColorRole colorRole, required SplashShapeKind kind, required Offset parallax, double? radius})
Creates a SplashBackdropSpec instance.
const

Properties

alignment Alignment
The alignment value used to configure this component.
final
colorRole SplashColorRole
The colorRole value used to configure this component.
final
hashCode int
The hash code for this object.
no setterinherited
kind SplashShapeKind
The kind value used to configure this component.
final
parallax Offset
The parallax value used to configure this component.
final
radius double?
The radius value used to configure this component.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
The size value used to configure this component.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited