SplashBubbleSpec class
Constructors
- SplashBubbleSpec({required double xFactor, required double size, required SplashColorRole colorRole, required double startDelay, required double travel, required double sway, required double drift, required double speed})
-
const
Properties
- colorRole → SplashColorRole
-
final
- drift → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double
-
final
- speed → double
-
final
- startDelay → double
-
final
- sway → double
-
final
- travel → double
-
final
- xFactor → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited