SplashBubbleSpec class

Provides the SplashBubbleSpec API for Neo-Brutalist Flutter interfaces.

Constructors

SplashBubbleSpec({required double xFactor, required double size, required SplashColorRole colorRole, required double startDelay, required double travel, required double sway, required double drift, required double speed})
Creates a SplashBubbleSpec instance.
const

Properties

colorRole SplashColorRole
The colorRole value used to configure this component.
final
drift double
The drift value used to configure this component.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
The size value used to configure this component.
final
speed double
The speed value used to configure this component.
final
startDelay double
The startDelay value used to configure this component.
final
sway double
The sway value used to configure this component.
final
travel double
The travel value used to configure this component.
final
xFactor double
The xFactor value used to configure this component.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited