SplashCargoSpec class
Constructors
- SplashCargoSpec({required double xFactor, required Size size, required SplashColorRole colorRole, required SplashShapeKind kind, required double depth, required double drift, required double bob, required double rotateTurns, required double appearDelay, double? radius})
-
const
Properties
- appearDelay → double
-
final
- bob → double
-
final
- colorRole → SplashColorRole
-
final
- depth → double
-
final
- drift → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → SplashShapeKind
-
final
- radius → double?
-
final
- rotateTurns → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → Size
-
final
- xFactor → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited