SplashCargoSpec class

Provides the SplashCargoSpec API for Neo-Brutalist Flutter interfaces.

Constructors

SplashCargoSpec({required double xFactor, required Size size, required SplashColorRole colorRole, required SplashShapeKind kind, required double depth, required double drift, required double bob, required double rotateTurns, required double appearDelay, double? radius})
Creates a SplashCargoSpec instance.
const

Properties

appearDelay double
The appearDelay value used to configure this component.
final
bob double
The bob value used to configure this component.
final
colorRole SplashColorRole
The colorRole value used to configure this component.
final
depth double
The depth value used to configure this component.
final
drift double
The drift value used to configure this component.
final
hashCode int
The hash code for this object.
no setterinherited
kind SplashShapeKind
The kind value used to configure this component.
final
radius double?
The radius value used to configure this component.
final
rotateTurns double
The rotateTurns value used to configure this component.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
The size value used to configure this component.
final
xFactor double
The xFactor value used to configure this component.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited