SplashConfig class
Constructors
-
SplashConfig({required Duration initialDuration, required Duration buildDuration, required Duration fillDuration, required Duration revealDuration, required Duration settleDuration, required Duration exitDuration, required Size logoFrameSize, required double liquidAmplitude, required double liquidHighlightStrength, required double motionIntensity, required List<
SplashShapeSpec> shapes, required List<SplashCargoSpec> fillCargo, required List<SplashBubbleSpec> bubbleWave, required List<SplashBackdropSpec> backdrops}) -
const
- SplashConfig.competition()
-
factory
Properties
-
backdrops
→ List<
SplashBackdropSpec> -
final
-
bubbleWave
→ List<
SplashBubbleSpec> -
final
- buildDuration → Duration
-
final
- buildStart → double
-
no setter
- exitDuration → Duration
-
final
- exitStart → double
-
no setter
-
fillCargo
→ List<
SplashCargoSpec> -
final
- fillDuration → Duration
-
final
- fillStart → double
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialDuration → Duration
-
final
- liquidAmplitude → double
-
final
- liquidHighlightStrength → double
-
final
- logoFrameSize → Size
-
final
- motionIntensity → double
-
final
- revealDuration → Duration
-
final
- revealStart → double
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settleDuration → Duration
-
final
- settleStart → double
-
no setter
-
shapes
→ List<
SplashShapeSpec> -
final
- totalDuration → Duration
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
phaseFor(
double timelineProgress) → SplashPhase -
progressForPhase(
SplashPhase phase, double timelineProgress, {Curve curve = Curves.linear}) → double -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited