SplashShapeSpec class

Provides the SplashShapeSpec API for Neo-Brutalist Flutter interfaces.

Constructors

SplashShapeSpec({required Alignment startAlignment, required Alignment targetAlignment, required Size size, required SplashColorRole colorRole, required SplashShapeKind kind, required double entryDelay, required double entrySpan, required Offset sway, required double hover, required double rotateTurns, required double liquidLift, required double impactBias, double? radius})
Creates a SplashShapeSpec instance.
const

Properties

colorRole SplashColorRole
The colorRole value used to configure this component.
final
entryDelay double
The entryDelay value used to configure this component.
final
entrySpan double
The entrySpan value used to configure this component.
final
hashCode int
The hash code for this object.
no setterinherited
hover double
The hover value used to configure this component.
final
impactBias double
The impactBias value used to configure this component.
final
kind SplashShapeKind
The kind value used to configure this component.
final
liquidLift double
The liquidLift value used to configure this component.
final
radius double?
The radius value used to configure this component.
final
rotateTurns double
The rotateTurns value used to configure this component.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
The size value used to configure this component.
final
startAlignment Alignment
The startAlignment value used to configure this component.
final
sway Offset
The sway value used to configure this component.
final
targetAlignment Alignment
The targetAlignment value used to configure this component.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited