SplashThemeData class
Provides the SplashThemeData API for Neo-Brutalist Flutter interfaces.
Constructors
-
SplashThemeData({required List<
Color> pageGradient, required Color atmosphereGlow, required Color surface, required Color surfaceAlt, required Color primary, required Color primarySoft, required Color outline, required Color shadowStrong, required Color shadowSoft, required Color textPrimary, required Color textMuted, required Color highlight}) -
Creates a SplashThemeData instance.
const
- SplashThemeData.fromPalette(NeoPalette palette)
-
Creates a SplashThemeData instance.
factory
Properties
- atmosphereGlow → Color
-
The atmosphereGlow value used to configure this component.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlight → Color
-
The highlight value used to configure this component.
final
- outline → Color
-
The outline value used to configure this component.
final
-
pageGradient
→ List<
Color> -
The pageGradient value used to configure this component.
final
- primary → Color
-
The primary value used to configure this component.
final
- primarySoft → Color
-
The primarySoft value used to configure this component.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowSoft → Color
-
The shadowSoft value used to configure this component.
final
- shadowStrong → Color
-
The shadowStrong value used to configure this component.
final
- surface → Color
-
The surface value used to configure this component.
final
- surfaceAlt → Color
-
The surfaceAlt value used to configure this component.
final
- textMuted → Color
-
The textMuted value used to configure this component.
final
- textPrimary → Color
-
The textPrimary value used to configure this component.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
SplashColorRole role) → Color - Executes resolve for this component.
-
resolveShadow(
SplashColorRole role) → Color - Executes resolveShadow for this component.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited