NeoDataTableRow class
Provides the NeoDataTableRow API for Neo-Brutalist Flutter interfaces.
Constructors
-
NeoDataTableRow({required List<
String> cells, bool highlight = false}) -
Creates a NeoDataTableRow instance.
const
Properties
-
cells
→ List<
String> -
The cells value used to configure this component.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlight → bool
-
The highlight value used to configure this component.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited