NeoTimelineEntry class
Provides the NeoTimelineEntry API for Neo-Brutalist Flutter interfaces.
Constructors
- NeoTimelineEntry({required String title, required String subtitle, String? meta, IconData? icon})
-
Creates a NeoTimelineEntry instance.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData?
-
The icon value used to configure this component.
final
- meta → String?
-
The meta value used to configure this component.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String
-
The subtitle value used to configure this component.
final
- title → String
-
The title value used to configure this component.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited